@@ -945,7 +945,7 @@
   [mailAccount setObject: delegates  forKey: @"delegates"];
 
   // 9. Security
-  if ([[_defaults mailCertificate] length])
+  if ([[self domainDefaults] mailCertificateEnabled] && [[_defaults mailCertificate] length])
     {
       security = [NSMutableDictionary new];
 
@@ -1129,7 +1129,7 @@
   return [authValue boolValue];
 }
 
-- (NSString *) googleAuthenticatorKey
+- (NSString *) totpKey
 {
 #if defined(MFA_CONFIG)
   NSString *key, *result;
